@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2013 by the Quassel Project                        *
+ *   Copyright (C) 2005-2014 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -118,6 +118,8 @@ private:
 
     template<class T>
     void dispatch(const T &protoMessage);
+    template<class T>
+    void dispatch(Peer *peer, const T &protoMessage);
 
     void handle(Peer *peer, const Protocol::SyncMessage &syncMessage);
     void handle(Peer *peer, const Protocol::RpcCall &rpcCall);
@@ -125,10 +127,10 @@ private:
     void handle(Peer *peer, const Protocol::InitData &initData);
 
     template<class T>
-    void handle(Peer *peer, T) { Q_UNUSED(peer); Q_ASSERT(0); }
+    void handle(Peer *, T) { Q_ASSERT(0); }
 
-    bool invokeSlot(QObject *receiver, int methodId, const QVariantList &params, QVariant &returnValue);
-    bool invokeSlot(QObject *receiver, int methodId, const QVariantList &params = QVariantList());
+    bool invokeSlot(QObject *receiver, int methodId, const QVariantList &params, QVariant &returnValue, Peer *peer = 0);
+    bool invokeSlot(QObject *receiver, int methodId, const QVariantList &params = QVariantList(), Peer *peer = 0);
 
     void requestInit(SyncableObject *obj);
     QVariantMap initData(SyncableObject *obj) const;
