@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2013 by the Quassel Project                        *
+ *   Copyright (C) 2005-2014 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,6 +28,11 @@
 #include <QHostAddress>
 #include <QDataStream>
 
+// We need to special-case Peer* in attached signals/slots, so typedef it for the meta type system
+class Peer;
+typedef Peer * PeerPtr;
+Q_DECLARE_METATYPE(PeerPtr)
+
 class SignedId
 {
 protected:
