@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2013 by the Quassel Project                        *
+ *   Copyright (C) 2005-2014 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -47,7 +47,7 @@ QString AboutDlg::about() const
 {
     QString res;
     res = tr("<b>A modern, distributed IRC Client</b><br><br>"
-             "&copy;2005-2013 by the Quassel Project<br>"
+             "&copy;%1 by the Quassel Project<br>"
              "<a href=\"http://quassel-irc.org\">http://quassel-irc.org</a><br>"
              "<a href=\"irc://irc.freenode.net/quassel\">#quassel</a> on <a href=\"http://www.freenode.net\">Freenode</a><br><br>"
              "Quassel IRC is dual-licensed under <a href=\"http://www.gnu.org/licenses/gpl-2.0.txt\">GPLv2</a> and "
@@ -55,7 +55,7 @@ QString AboutDlg::about() const
              "Most icons are &copy; by the <a href=\"http://www.oxygen-icons.org\">Oxygen Team</a> and used under the "
              "<a href=\"http://www.gnu.org/licenses/lgpl.html\">LGPL</a>.<br><br>"
              "Please use <a href=\"http://bugs.quassel-irc.org\">http://bugs.quassel-irc.org</a> to report bugs."
-        );
+        ).arg("2005-2014");
 
     return res;
 }
@@ -89,6 +89,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Terje \"tan\" Andersen</b></dt><dd>Norwegian translation, documentation</dd>"
                               "<dt><b>Jens \"amiconn\" Arnold</b></dt><dd>Postgres migration fixes</dd>"
                               "<dt><b>Adolfo Jayme Barrientos</b></dt><dd>Spanish translation</dd>"
+                              "<dt><b>Pete \"elbeardmorez\" Beardmore</b></dt><dd>Linewrap for input line</dd>"
                               "<dt><b>Rafael \"EagleScreen\" Belmonte</b></dt><dd>Spanish translation</dd>"
                               "<dt><b>Sergiu Bivol</b></dt><dd>Romanian translation</dd>"
                               "<dt><b>Bruno Brigras</b></dt><dd>Crash fixes</dd>"
@@ -119,8 +120,10 @@ QString AboutDlg::contributors() const
                               "<dt><b>\"Gryllida\"</b></dt><dd>IRC parser improvements</dd>"
                               "<dt><b>H. İbrahim \"igungor\" Güngör</b></dt><dd>Turkish translation</dd>"
                               "<dt><b>Jiri Grönroos</b></dt><dd>Finnish translation</dd>"
+                              "<dt><b>Chris \"Zren\" H</b></dt><dd>Various improvements</dd>"
                               "<dt><b>Edward Hades</b></dt><dd>Russian translation</dd>"
                               "<dt><b>John \"nox\" Hand</b></dt><dd>Former All-Seeing Eye logo</dd>"
+                              "<dt><b>Adam \"2kah\" Harwood</b></dt><dd>ChatView improvements</dd>"
                               "<dt><b>Jonas \"Dante\" Heese</b></dt><dd>Project founder, various improvements</dd>"
                               "<dt><b>Thomas \"Datafreak\" Hogh</b></dt><dd>Windows builder</dd>"
                               "<dt><b>Johannes \"j0hu\" Huber</b></dt><dd>Many fixes and features, bug triaging</dd>"
@@ -137,6 +140,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Jerome \"Adys\" Leclanche</b></dt><dd>Context menu fixes</dd>"
                               "<dt><b>Hendrik \"nevcairiel\" Leppkes</b></dt><dd>Various features</dd>"
                               "<dt><b>Jason Lynch</b></dt><dd>Bugfixes</dd>"
+                              "<dt><b>Awad \"firesock\" Mackie</b></dt><dd>ChatView improvements</dd>"
                               "<dt><b>Michael \"mamarley\" Marley</b></dt><dd>Various fixes and improvements</dd>"
                               "<dt><b>Martin \"m4yer\" Mayer</b></dt><dd>German translation</dd>"
                               "<dt><b>Daniel \"hydrogen\" Meltzer</b></dt><dd>Various fixes and improvements</dd>"
