@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2013 by the Quassel Project                        *
+ *   Copyright (C) 2005-2014 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,7 +53,7 @@ MultiLineEdit::MultiLineEdit(QWidget *parent)
 #endif
 
     setMode(SingleLine);
-    setWordWrapEnabled(false);
+    setLineWrapEnabled(false);
     reset();
 
     connect(this, SIGNAL(textChanged()), this, SLOT(on_textChanged()));
@@ -98,6 +98,13 @@ void MultiLineEdit::setMode(Mode mode)
 }
 
 
+void MultiLineEdit::setLineWrapEnabled(bool enable)
+{
+    setLineWrapMode(enable ? WidgetWidth : NoWrap);
+    updateSizeHint();
+}
+
+
 void MultiLineEdit::setMinHeight(int lines)
 {
     if (lines == _minHeight)
@@ -207,13 +214,6 @@ void MultiLineEdit::setSpellCheckEnabled(bool enable)
 }
 
 
-void MultiLineEdit::setWordWrapEnabled(bool enable)
-{
-    setLineWrapMode(enable ? WidgetWidth : NoWrap);
-    updateSizeHint();
-}
-
-
 void MultiLineEdit::setPasteProtectionEnabled(bool enable, QWidget *)
 {
     _pasteProtectionEnabled = enable;
